@@ -167,9 +167,8 @@ def configure_stripe_client():
     # Allow ourselves to retry retriable network errors 5 times
     # https://github.com/stripe/stripe-python/tree/a9a8d754b73ad47bdece6ac4b4850822fa19db4e#configuring-automatic-retries
     stripe.max_network_retries = 15
-    # Configure client-side network timeout of 1 second
-    # https://github.com/stripe/stripe-python/tree/a9a8d754b73ad47bdece6ac4b4850822fa19db4e#configuring-a-client
-    client = stripe.http_client.RequestsClient(timeout=15)
+    # Configure client with a default timeout of 80 seconds
+    client = stripe.http_client.RequestsClient()
     apply_request_timer_to_client(client)
     stripe.default_http_client = client
     # Set stripe logging to INFO level
@@ -662,6 +661,18 @@ def should_sync_event(events_obj, object_type, id_to_created_map):
         id_to_created_map[event_resource_id] = events_obj.created
     return should_sync
 
+def recursive_to_dict(some_obj):
+    if isinstance(some_obj, stripe.stripe_object.StripeObject):
+        return recursive_to_dict(dict(some_obj))
+
+    if isinstance(some_obj, list):
+        return [recursive_to_dict(item) for item in some_obj]
+
+    if isinstance(some_obj, dict):
+        return {key: recursive_to_dict(value) for key, value in some_obj.items()}
+
+    # Else just return
+    return some_obj
 
 def sync_event_updates(stream_name):
     '''
@@ -728,7 +739,8 @@ def sync_event_updates(stream_name):
 
                         invoice_obj['lines']['data'] = filtered_line_items
 
-                rec = unwrap_data_objects(event_resource_obj.to_dict_recursive())
+                rec = recursive_to_dict(event_resource_obj)
+                rec = unwrap_data_objects(rec)
                 rec = reduce_foreign_keys(rec, stream_name)
                 rec["updated"] = events_obj.created
                 rec = transformer.transform(
